# Warping the needs of a "pip search" command necessity through PyPi.org 
Just `pip_search anything`

---
0.0.4 Update : 
- Adding multiple keywords support
- Adding usage info

All changes thanks to @Maxz44
